@@ -11,6 +11,7 @@ import locale
 import re
 import getopt
 import sys
+import shlex
 
 from subprocess import Popen, PIPE, STDOUT
 from pathlib import Path
@@ -221,7 +222,7 @@ class Pri3oDmenuDesktop:
         applist.sort(key=lambda x: self.apps[x]["prio"])
 
         # run dmenu and read choice
-        p = Popen(self.dmenu_cmd.split(), stdout=PIPE, stdin=PIPE, stderr=PIPE)
+        p = Popen(shlex.split(self.dmenu_cmd), stdout=PIPE, stdin=PIPE, stderr=PIPE)
         choice = p.communicate(input=bytearray("\n".join(applist), encoding='utf-8'))
         return choice[0].decode()[:-1].split("\n")[0]
 
